@@ -11,9 +11,8 @@
 #'
 #' @param is.in2        A logical vector for output 2, TRUE iff row is in the match.
 #'
-#' @param prefer_test   If TRUE, prefers higher test statistic more than
-#'                      the group size proportion; default is FALSE if props
-#'                      is specified, TRUE if it is not.
+#' @param prefer_test   If TRUE, it prioritizes the test statistic more than
+#'                      the group size proportion.
 #'
 #' @inheritParams match_groups
 #'
@@ -29,7 +28,7 @@ compare_ldamatch_outputs <- function(is.in1,
                                      condition,
                                      covariates = matrix(),
                                      halting_test = NA,
-                                     props = NULL,
+                                     props = prop.table(table(condition)),
                                      prefer_test = is.null(props),
                                      tiebreaker = NULL) {
     exception1 <- (class(is.in1) == "try-error")
@@ -60,22 +59,28 @@ compare_ldamatch_outputs <- function(is.in1,
     for (test_stat in c(prefer_test, !prefer_test)) {
         # compare test statistic
         if (test_stat && is.function(halting_test)) {
-            p_matched1 <- calc_p_value(condition[is.in1], covariates[is.in1, , drop = FALSE], halting_test)
-            p_matched2 <- calc_p_value(condition[is.in2], covariates[is.in2, , drop = FALSE], halting_test)
+            p_matched1 <-
+                calc_p_value(condition[is.in1], covariates[is.in1, , drop = FALSE], halting_test)
+            p_matched2 <-
+                calc_p_value(condition[is.in2], covariates[is.in2, , drop = FALSE], halting_test)
             if (p_matched1 != p_matched2)
                 return(p_matched1 - p_matched2)
             # compare tiebreaker statistic
             if (is.function(tiebreaker)) {
-                p_tiebreaker1 <- calc_p_value(condition[is.in1], covariates[is.in1, , drop = FALSE], tiebreaker)
-                p_tiebreaker2 <- calc_p_value(condition[is.in2], covariates[is.in2, , drop = FALSE], tiebreaker)
+                p_tiebreaker1 <-
+                    calc_p_value(condition[is.in1], covariates[is.in1, , drop = FALSE], tiebreaker)
+                p_tiebreaker2 <-
+                    calc_p_value(condition[is.in2], covariates[is.in2, , drop = FALSE], tiebreaker)
                 if (p_tiebreaker1 != p_tiebreaker2)
                     return(p_tiebreaker1 - p_tiebreaker2)
             }
         } else {
             # compare divergence from expected balance
             props <- .normalize_props(props, condition)
-            divergence1 <- .calc_subject_balance_divergence(table(condition[is.in1]), props)
-            divergence2 <- .calc_subject_balance_divergence(table(condition[is.in2]), props)
+            divergence1 <-
+                .calc_subject_balance_divergence(table(condition[is.in1]), props)
+            divergence2 <-
+                .calc_subject_balance_divergence(table(condition[is.in2]), props)
             if (divergence1 != divergence2)
                 return(divergence2 - divergence1)
         }
@@ -84,6 +89,67 @@ compare_ldamatch_outputs <- function(is.in1,
 }
 
 
+#' Compares outputs of ldamatch runs using internally normalized parameters.
+#'
+#' @seealso \code{\link{compare_ldamatch_outputs}} for operation and meaning of
+#' parameters.
+#'
+#' @inheritParams compare_ldamatch_outputs
+#'
+#' @return A number that is > 0 if is.in1 is a better solution than is.in2,
+#'         < 0 if is.in1 is a worse solution than is.in2, or
+#'         0 if the two solutions are equivalent (not necessarily identical).
+#'
+#' @keywords internal
+.internally_compare_ldamatch_outputs <- function(is.in1,
+                                                 is.in2,
+                                                 condition,
+                                                 covariates,
+                                                 halting_test,
+                                                 props,
+                                                 prefer_test,
+                                                 tiebreaker) {
+    exception1 <- (class(is.in1) == "try-error")
+    exception2 <- (class(is.in2) == "try-error")
+    if (exception1 || exception2)
+        return(exception2 - exception1)
+    # compare number of excluded subjects
+    num_excluded1 <- sum(!is.in1)
+    num_excluded2 <- sum(!is.in2)
+    if (num_excluded1 != num_excluded2)
+        return(num_excluded2 - num_excluded1)
+    for (test_stat in c(prefer_test, !prefer_test)) {
+        # compare test statistic
+        if (test_stat && is.function(halting_test)) {
+            p_matched1 <-
+                calc_p_value(condition[is.in1], covariates[is.in1, , drop = FALSE], halting_test)
+            p_matched2 <-
+                calc_p_value(condition[is.in2], covariates[is.in2, , drop = FALSE], halting_test)
+            if (abs(p_matched1 - p_matched2) > .tolerance)
+                return(p_matched1 - p_matched2)
+            # compare tiebreaker statistic
+            if (is.function(tiebreaker)) {
+                p_tiebreaker1 <-
+                    calc_p_value(condition[is.in1], covariates[is.in1, , drop = FALSE], tiebreaker)
+                p_tiebreaker2 <-
+                    calc_p_value(condition[is.in2], covariates[is.in2, , drop = FALSE], tiebreaker)
+                if (abs(p_tiebreaker1 - p_tiebreaker2) > .tolerance)
+                    return(p_tiebreaker1 - p_tiebreaker2)
+            }
+        } else {
+            # compare divergence from expected balance
+            divergence1 <-
+                .calc_subject_balance_divergence(table(condition[is.in1]), props)
+            divergence2 <-
+                .calc_subject_balance_divergence(table(condition[is.in2]), props)
+            if (abs(divergence1 - divergence2) > .tolerance)
+                return(divergence2 - divergence1)
+        }
+    }
+    return(0)
+}
+
+
 #' Calculates basic metrics about ldamatch search result.
 #'
 #' @param is.in        The output of \code{\link{match_groups}()}:
@@ -93,8 +159,8 @@ compare_ldamatch_outputs <- function(is.in1,
 #' \item{all.is.in}{all results as a list;}
 #' \item{is.in}{simply the first item in all.is.in or the error contained
 #' in is.in if there was an error running \code{\link{match_groups}};}
-#' \item{num_excluded}{the number of excluded subjects), p_matched
-#'    (the test statistic from halting_test for the matched groups);}
+#' \item{num_excluded}{the number of excluded subjects;}
+#' \item{p_matched}{the test statistic from halting_test for the matched groups;}
 #' \item{p_tiebreaker}{the test statistic from tiebreaker for the matched groups; and}
 #' \item{balance_divergence}{a value characterizing the deviation
 #'   from the expected group size proportions specified in props.}
@@ -127,25 +193,34 @@ calc_metrics <- function(is.in,
         is.in
     else
         list(is.in)
-    is.in <- all.is.in[[1]]
     if (length(covariates) == 0) {
         p_matched <- Inf
         p_tiebreaker <- Inf
+        balance_divergence <- 0
     } else {
         covariates <- as.matrix(covariates)
-        p_matched <- suppressWarnings(calc_p_value(condition[is.in], covariates[is.in, , drop = FALSE], halting_test))
+        p_matched <-
+            suppressWarnings(sapply(all.is.in, function(is.in)
+                calc_p_value(condition[is.in], covariates[is.in, , drop = FALSE], halting_test)))
         p_tiebreaker <- if (is.function(tiebreaker)) {
-            suppressWarnings(calc_p_value(condition[is.in], covariates[is.in, , drop = FALSE], tiebreaker))
+            suppressWarnings(sapply(all.is.in, function(is.in)
+                calc_p_value(condition[is.in], covariates[is.in, , drop = FALSE], tiebreaker)))
         } else {
             NA
         }
+        balance_divergence <-
+            sapply(all.is.in, function(is.in)
+                .calc_subject_balance_divergence(
+                    table(condition[is.in]),
+                    .normalize_props(props, condition)
+                ))
     }
     list(
         all.is.in = all.is.in,
-        is.in = is.in,
-        num_excluded = sum(!is.in),
+        is.in = all.is.in[[1]],
+        num_excluded = sum(!all.is.in[[1]]),
         p_matched = p_matched,
         p_tiebreaker = p_tiebreaker,
-        balance_divergence = .calc_subject_balance_divergence(table(condition[is.in]), .normalize_props(props, condition))
+        balance_divergence = balance_divergence
     )
 }
